==========================
Sphinx Traceability plugin
==========================

Sphinx plugin that allows defining documentation items and relations between those items. Can be used
as a requirements management tool for e.g. ISO26262 projects.

.. contents:: `Contents`
    :depth: 2
    :local:

.. toctree::
    :maxdepth: 2

    goal
    installation
    configuration
    usage
    contributing

-------
Process
-------

The Melexis.SWCC (SoftWare Competence Center) process has a Guideline for documenting in reStructuredText (RST).
It holds guidelines for using the traceability plugin with naming conventions, templates, etc.
